==> klogshow_1.0.3.orig.tar.gz: klogshow-1.0.3/src/confWindow.h <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   pinon.pierre@gmail.com                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CONFWINDOW_H
#define CONFWINDOW_H

#include <QtGui>

#include "klogshow.h"
#include <ui_confWindow.h>

class confWindow : public QDialog, public Ui::confWindow
{
		Q_OBJECT
	public:
		confWindow ( QString confFileName, QDialog *parent = 0 );
		~confWindow();
	private slots:
		void 	on_btnSave_clicked();
		void		on_btnCancel_clicked();
		void 	on_btnAdd_clicked();
		void		on_btnEdit_clicked();
		void		on_btnDel_clicked();
		void 	on_toolLogFile_clicked();
		void 	on_btnBackColor_clicked();
		void 	on_btnTextColor_clicked();
		void 	on_btnFont_clicked();
		void 	on_chkDecor_stateChanged();
		void		on_chkTitle_stateChanged();
		void		on_lstLogFiles_currentItemChanged();
		void		on_chkRoot_stateChanged();
		void 	on_radKdesu_toggled();
		void		on_radGnomesu_toggled();
	private:
		void		loadConfig();
		void 	saveConfig();

		QString	confPath;
};

#endif

==> klogshow_1.0.4.orig.tar.gz: klogshow-1.0.4/src/confWindow.h <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   xes@xesnet.fr                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CONFWINDOW_H
#define CONFWINDOW_H

#include <QtGui>

#include "klogshow.h"
#include <ui_confWindow.h>

class confWindow : public QDialog, public Ui::confWindow
{
		Q_OBJECT
	public:
		confWindow ( QString confFileName, QDialog *parent = 0 );
		~confWindow();
	private slots:
		void 	on_btnSave_clicked();
		void		on_btnCancel_clicked();
		void 	on_btnAdd_clicked();
		void		on_btnEdit_clicked();
		void		on_btnDel_clicked();
		void 	on_toolLogFile_clicked();
		void 	on_btnBackColorTop_clicked();
		void 	on_btnBackColorBottom_clicked();
		void 	on_btnTextColor_clicked();
		void 	on_btnFont_clicked();
		void 	on_chkDecor_stateChanged();
		void		on_chkTitle_stateChanged();
		void		on_lstLogFiles_currentItemChanged();
		void		on_chkRoot_stateChanged();
		void 	on_radKdesu_toggled();
		void		on_radGnomesu_toggled();
	private:
		void		loadConfig();
		void 	saveConfig();
		void		makeGradient();
		
		QString	confPath;
		QColor	backColorTop;
		QColor	backColorBottom;
};

#endif
